You are viewing a plain text version of this content. The canonical link for it is here.
Posted to user@hbase.apache.org by Lukáš Drbal <lu...@gmail.com> on 2013/08/31 20:25:32 UTC

NPE in restore_snapshot

Hi,
i catch NPE when i try restore my snapshot.

Snapshot is taken from online table and exported to another cluster via:
hbase org.apache.hadoop.hbase.snapshot.ExportSnapshot -snapshot
fb_posts-2013-08-31 -copy-to hdfs://hadoops-master:9000/hbase -chuser hbase
-chgroup hbase -mappers 14


OT: files on hadoops-master cluster has permission hadoop:hbase (HDFS).
Maybe a mistake? I specify -chuser and -chroup in export : ) I fix it with
hadoop fs -chown -R hbase:hbase /hbase

hbase(main):006:0> list_snapshots
SNAPSHOT                                                              TABLE
+ CREATION
TIME

 fb_comments-2013-08-27
fb_comments (Tue Aug 27 08:42:01 +0000
2013)

 fb_posts-2013-08-26
fb_posts (Mon Aug 26 19:26:04 +0000
2013)

 fb_posts-2013-08-31
fb_posts (Sat Aug 31 17:22:52 +0000
2013)

3 row(s) in 0.0220 seconds

SnapshotInfo: http://pastebin.com/dLS6tzTJ

I see here a lot NOT_FOUND files, duno why and that's imho reason for this
fail.

hbase(main):007:0> list
TABLE

fb_comments

fb_posts

fb_posts_old

test

4 row(s) in 0.0180 seconds

fb_posts_old are cloned snapshot from fb_posts-2013-08-26

hbase(main):008:0> is_disabled 'fb_posts'
true

0 row(s) in 0.0080 seconds

hbase(main):009:0> restore_snapshot 'fb_posts-2013-08-31'

output error: http://pastebin.com/tFsnGLha

Master log: http://pastebin.com/yfLjJyfc

RS logs are clean :( Log level are set to DEBUG


Please excuse my bad english.

-- 
Save The World - http://www.worldcommunitygrid.org/
http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR

LesTR

Re: NPE in restore_snapshot

Posted by Lukáš Drbal <lu...@gmail.com>.
Thanks for response Matteo. I haven't problem with this NPE, i want only
report it. Good to know about HBASE-8760.

Lukas

2013/9/1 Matteo Bertozzi <th...@gmail.com>

> one region of the table has no SERVER_QUALIFIER, that means it was never
> assigned.
> and you get the NPE during the snapshot taken before restoring.
> The workaround is drop the table and use clone_snapshot instead.
>
> (The NPE was fixed as part of HBASE-8760, which should be part of 0.94.12)
>
>
>
> Matteo
>
>
>
> On Sat, Aug 31, 2013 at 7:45 PM, Lukáš Drbal <lu...@gmail.com>
> wrote:
>
> > Ach, sorry.
> > Hbase 0.94.11 and hadoop 1.0.3
> >
> >
> > 2013/8/31 Ted Yu <yu...@gmail.com>
> >
> > > What version of HBase are you using ?
> > >
> > > According to output, the NPE seems to point to the following line
> > > in DisabledTableSnapshotHandler.java (tip of 0.94):
> > >
> > >       LOG.info("Starting to write region info and WALs for regions for
> > > offline snapshot:"
> > >           + SnapshotDescriptionUtils.toString(snapshot));
> > >
> > > It is unlikely the statement which caused NPE. Knowing the release
> would
> > > help pinpoint the exact location.
> > >
> > > Cheers
> > >
> > >
> > > On Sat, Aug 31, 2013 at 11:25 AM, Lukáš Drbal <lu...@gmail.com>
> > > wrote:
> > >
> > > > Hi,
> > > > i catch NPE when i try restore my snapshot.
> > > >
> > > > Snapshot is taken from online table and exported to another cluster
> > via:
> > > > hbase org.apache.hadoop.hbase.snapshot.ExportSnapshot -snapshot
> > > > fb_posts-2013-08-31 -copy-to hdfs://hadoops-master:9000/hbase -chuser
> > > hbase
> > > > -chgroup hbase -mappers 14
> > > >
> > > >
> > > > OT: files on hadoops-master cluster has permission hadoop:hbase
> (HDFS).
> > > > Maybe a mistake? I specify -chuser and -chroup in export : ) I fix it
> > > with
> > > > hadoop fs -chown -R hbase:hbase /hbase
> > > >
> > > > hbase(main):006:0> list_snapshots
> > > > SNAPSHOT
> > >  TABLE
> > > > + CREATION
> > > > TIME
> > > >
> > > >  fb_comments-2013-08-27
> > > > fb_comments (Tue Aug 27 08:42:01 +0000
> > > > 2013)
> > > >
> > > >  fb_posts-2013-08-26
> > > > fb_posts (Mon Aug 26 19:26:04 +0000
> > > > 2013)
> > > >
> > > >  fb_posts-2013-08-31
> > > > fb_posts (Sat Aug 31 17:22:52 +0000
> > > > 2013)
> > > >
> > > > 3 row(s) in 0.0220 seconds
> > > >
> > > > SnapshotInfo: http://pastebin.com/dLS6tzTJ
> > > >
> > > > I see here a lot NOT_FOUND files, duno why and that's imho reason for
> > > this
> > > > fail.
> > > >
> > > > hbase(main):007:0> list
> > > > TABLE
> > > >
> > > > fb_comments
> > > >
> > > > fb_posts
> > > >
> > > > fb_posts_old
> > > >
> > > > test
> > > >
> > > > 4 row(s) in 0.0180 seconds
> > > >
> > > > fb_posts_old are cloned snapshot from fb_posts-2013-08-26
> > > >
> > > > hbase(main):008:0> is_disabled 'fb_posts'
> > > > true
> > > >
> > > > 0 row(s) in 0.0080 seconds
> > > >
> > > > hbase(main):009:0> restore_snapshot 'fb_posts-2013-08-31'
> > > >
> > > > output error: http://pastebin.com/tFsnGLha
> > > >
> > > > Master log: http://pastebin.com/yfLjJyfc
> > > >
> > > > RS logs are clean :( Log level are set to DEBUG
> > > >
> > > >
> > > > Please excuse my bad english.
> > > >
> > > > --
> > > > Save The World - http://www.worldcommunitygrid.org/
> > > >
> > http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR
> > > >
> > > > LesTR
> > > >
> > >
> >
> >
> >
> > --
> > Save The World - http://www.worldcommunitygrid.org/
> > http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR
> >
> > LesTR
> >
>



-- 
Save The World - http://www.worldcommunitygrid.org/
http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR

LesTR

Re: NPE in restore_snapshot

Posted by Matteo Bertozzi <th...@gmail.com>.
one region of the table has no SERVER_QUALIFIER, that means it was never
assigned.
and you get the NPE during the snapshot taken before restoring.
The workaround is drop the table and use clone_snapshot instead.

(The NPE was fixed as part of HBASE-8760, which should be part of 0.94.12)



Matteo



On Sat, Aug 31, 2013 at 7:45 PM, Lukáš Drbal <lu...@gmail.com> wrote:

> Ach, sorry.
> Hbase 0.94.11 and hadoop 1.0.3
>
>
> 2013/8/31 Ted Yu <yu...@gmail.com>
>
> > What version of HBase are you using ?
> >
> > According to output, the NPE seems to point to the following line
> > in DisabledTableSnapshotHandler.java (tip of 0.94):
> >
> >       LOG.info("Starting to write region info and WALs for regions for
> > offline snapshot:"
> >           + SnapshotDescriptionUtils.toString(snapshot));
> >
> > It is unlikely the statement which caused NPE. Knowing the release would
> > help pinpoint the exact location.
> >
> > Cheers
> >
> >
> > On Sat, Aug 31, 2013 at 11:25 AM, Lukáš Drbal <lu...@gmail.com>
> > wrote:
> >
> > > Hi,
> > > i catch NPE when i try restore my snapshot.
> > >
> > > Snapshot is taken from online table and exported to another cluster
> via:
> > > hbase org.apache.hadoop.hbase.snapshot.ExportSnapshot -snapshot
> > > fb_posts-2013-08-31 -copy-to hdfs://hadoops-master:9000/hbase -chuser
> > hbase
> > > -chgroup hbase -mappers 14
> > >
> > >
> > > OT: files on hadoops-master cluster has permission hadoop:hbase (HDFS).
> > > Maybe a mistake? I specify -chuser and -chroup in export : ) I fix it
> > with
> > > hadoop fs -chown -R hbase:hbase /hbase
> > >
> > > hbase(main):006:0> list_snapshots
> > > SNAPSHOT
> >  TABLE
> > > + CREATION
> > > TIME
> > >
> > >  fb_comments-2013-08-27
> > > fb_comments (Tue Aug 27 08:42:01 +0000
> > > 2013)
> > >
> > >  fb_posts-2013-08-26
> > > fb_posts (Mon Aug 26 19:26:04 +0000
> > > 2013)
> > >
> > >  fb_posts-2013-08-31
> > > fb_posts (Sat Aug 31 17:22:52 +0000
> > > 2013)
> > >
> > > 3 row(s) in 0.0220 seconds
> > >
> > > SnapshotInfo: http://pastebin.com/dLS6tzTJ
> > >
> > > I see here a lot NOT_FOUND files, duno why and that's imho reason for
> > this
> > > fail.
> > >
> > > hbase(main):007:0> list
> > > TABLE
> > >
> > > fb_comments
> > >
> > > fb_posts
> > >
> > > fb_posts_old
> > >
> > > test
> > >
> > > 4 row(s) in 0.0180 seconds
> > >
> > > fb_posts_old are cloned snapshot from fb_posts-2013-08-26
> > >
> > > hbase(main):008:0> is_disabled 'fb_posts'
> > > true
> > >
> > > 0 row(s) in 0.0080 seconds
> > >
> > > hbase(main):009:0> restore_snapshot 'fb_posts-2013-08-31'
> > >
> > > output error: http://pastebin.com/tFsnGLha
> > >
> > > Master log: http://pastebin.com/yfLjJyfc
> > >
> > > RS logs are clean :( Log level are set to DEBUG
> > >
> > >
> > > Please excuse my bad english.
> > >
> > > --
> > > Save The World - http://www.worldcommunitygrid.org/
> > >
> http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR
> > >
> > > LesTR
> > >
> >
>
>
>
> --
> Save The World - http://www.worldcommunitygrid.org/
> http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR
>
> LesTR
>

Re: NPE in restore_snapshot

Posted by Lukáš Drbal <lu...@gmail.com>.
Ach, sorry.
Hbase 0.94.11 and hadoop 1.0.3


2013/8/31 Ted Yu <yu...@gmail.com>

> What version of HBase are you using ?
>
> According to output, the NPE seems to point to the following line
> in DisabledTableSnapshotHandler.java (tip of 0.94):
>
>       LOG.info("Starting to write region info and WALs for regions for
> offline snapshot:"
>           + SnapshotDescriptionUtils.toString(snapshot));
>
> It is unlikely the statement which caused NPE. Knowing the release would
> help pinpoint the exact location.
>
> Cheers
>
>
> On Sat, Aug 31, 2013 at 11:25 AM, Lukáš Drbal <lu...@gmail.com>
> wrote:
>
> > Hi,
> > i catch NPE when i try restore my snapshot.
> >
> > Snapshot is taken from online table and exported to another cluster via:
> > hbase org.apache.hadoop.hbase.snapshot.ExportSnapshot -snapshot
> > fb_posts-2013-08-31 -copy-to hdfs://hadoops-master:9000/hbase -chuser
> hbase
> > -chgroup hbase -mappers 14
> >
> >
> > OT: files on hadoops-master cluster has permission hadoop:hbase (HDFS).
> > Maybe a mistake? I specify -chuser and -chroup in export : ) I fix it
> with
> > hadoop fs -chown -R hbase:hbase /hbase
> >
> > hbase(main):006:0> list_snapshots
> > SNAPSHOT
>  TABLE
> > + CREATION
> > TIME
> >
> >  fb_comments-2013-08-27
> > fb_comments (Tue Aug 27 08:42:01 +0000
> > 2013)
> >
> >  fb_posts-2013-08-26
> > fb_posts (Mon Aug 26 19:26:04 +0000
> > 2013)
> >
> >  fb_posts-2013-08-31
> > fb_posts (Sat Aug 31 17:22:52 +0000
> > 2013)
> >
> > 3 row(s) in 0.0220 seconds
> >
> > SnapshotInfo: http://pastebin.com/dLS6tzTJ
> >
> > I see here a lot NOT_FOUND files, duno why and that's imho reason for
> this
> > fail.
> >
> > hbase(main):007:0> list
> > TABLE
> >
> > fb_comments
> >
> > fb_posts
> >
> > fb_posts_old
> >
> > test
> >
> > 4 row(s) in 0.0180 seconds
> >
> > fb_posts_old are cloned snapshot from fb_posts-2013-08-26
> >
> > hbase(main):008:0> is_disabled 'fb_posts'
> > true
> >
> > 0 row(s) in 0.0080 seconds
> >
> > hbase(main):009:0> restore_snapshot 'fb_posts-2013-08-31'
> >
> > output error: http://pastebin.com/tFsnGLha
> >
> > Master log: http://pastebin.com/yfLjJyfc
> >
> > RS logs are clean :( Log level are set to DEBUG
> >
> >
> > Please excuse my bad english.
> >
> > --
> > Save The World - http://www.worldcommunitygrid.org/
> > http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR
> >
> > LesTR
> >
>



-- 
Save The World - http://www.worldcommunitygrid.org/
http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR

LesTR

Re: NPE in restore_snapshot

Posted by Ted Yu <yu...@gmail.com>.
What version of HBase are you using ?

According to output, the NPE seems to point to the following line
in DisabledTableSnapshotHandler.java (tip of 0.94):

      LOG.info("Starting to write region info and WALs for regions for
offline snapshot:"
          + SnapshotDescriptionUtils.toString(snapshot));

It is unlikely the statement which caused NPE. Knowing the release would
help pinpoint the exact location.

Cheers


On Sat, Aug 31, 2013 at 11:25 AM, Lukáš Drbal <lu...@gmail.com> wrote:

> Hi,
> i catch NPE when i try restore my snapshot.
>
> Snapshot is taken from online table and exported to another cluster via:
> hbase org.apache.hadoop.hbase.snapshot.ExportSnapshot -snapshot
> fb_posts-2013-08-31 -copy-to hdfs://hadoops-master:9000/hbase -chuser hbase
> -chgroup hbase -mappers 14
>
>
> OT: files on hadoops-master cluster has permission hadoop:hbase (HDFS).
> Maybe a mistake? I specify -chuser and -chroup in export : ) I fix it with
> hadoop fs -chown -R hbase:hbase /hbase
>
> hbase(main):006:0> list_snapshots
> SNAPSHOT                                                              TABLE
> + CREATION
> TIME
>
>  fb_comments-2013-08-27
> fb_comments (Tue Aug 27 08:42:01 +0000
> 2013)
>
>  fb_posts-2013-08-26
> fb_posts (Mon Aug 26 19:26:04 +0000
> 2013)
>
>  fb_posts-2013-08-31
> fb_posts (Sat Aug 31 17:22:52 +0000
> 2013)
>
> 3 row(s) in 0.0220 seconds
>
> SnapshotInfo: http://pastebin.com/dLS6tzTJ
>
> I see here a lot NOT_FOUND files, duno why and that's imho reason for this
> fail.
>
> hbase(main):007:0> list
> TABLE
>
> fb_comments
>
> fb_posts
>
> fb_posts_old
>
> test
>
> 4 row(s) in 0.0180 seconds
>
> fb_posts_old are cloned snapshot from fb_posts-2013-08-26
>
> hbase(main):008:0> is_disabled 'fb_posts'
> true
>
> 0 row(s) in 0.0080 seconds
>
> hbase(main):009:0> restore_snapshot 'fb_posts-2013-08-31'
>
> output error: http://pastebin.com/tFsnGLha
>
> Master log: http://pastebin.com/yfLjJyfc
>
> RS logs are clean :( Log level are set to DEBUG
>
>
> Please excuse my bad english.
>
> --
> Save The World - http://www.worldcommunitygrid.org/
> http://www.worldcommunitygrid.org/stat/viewMemberInfo.do?userName=LesTR
>
> LesTR
>